==> haskell-storable-complex-0.2.3.0-320-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-Hc9DKW4impqJIewcSFwGZM
key:                  storable-complex-0.2.3.0-Hc9DKW4impqJIewcSFwGZM
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  6ca8de7a32481ebaf652781773362ae7
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-Hc9DKW4impqJIewcSFwGZM
depends:
    base-4.17.2.1 base-orphans-0.9.3-3KtSPbzI9SY3SAwdDkke64

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-321-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-JAhwaGxSZ19ByJAwHkPl4p
key:                  storable-complex-0.2.3.0-JAhwaGxSZ19ByJAwHkPl4p
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  0d68074a292763602b462759e1b21ea1
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-JAhwaGxSZ19ByJAwHkPl4p
depends:
    base-4.17.2.1 base-orphans-0.9.3-mLaWXjfYyEJrlxeLudKlO

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
